# -*- coding: utf-8 -*-
from unittest import TestCase

from tibetan import util


class UtilTestCase(TestCase):

    def test_decode(self):
        tibetan = "ཕྱུག་པོ་གཟིགས་སོང་།"
        raw = ("\xe0\xbd\x95\xe0\xbe\xb1\xe0\xbd\xb4\xe0\xbd\x82\xe0\xbc"
               "\x8b\xe0\xbd\x94\xe0\xbd\xbc\xe0\xbc\x8b\xe0\xbd\x82\xe0"
               "\xbd\x9f\xe0\xbd\xb2\xe0\xbd\x82\xe0\xbd\xa6\xe0\xbc\x8b"
               "\xe0\xbd\xa6\xe0\xbd\xbc\xe0\xbd\x84\xe0\xbc\x8b\xe0\xbc"
               "\x8d")
        unicode = (u"\u0f55\u0fb1\u0f74\u0f42\u0f0b\u0f54\u0f7c\u0f0b"
                   u"\u0f42\u0f5f\u0f72\u0f42\u0f66\u0f0b\u0f66\u0f7c"
                   u"\u0f44\u0f0b\u0f0d")
        tibetanDecoded = util.decode(tibetan)
        rawDecoded = util.decode(raw)
        unicodeDecoded = util.decode(unicode)
        self.assertTrue(tibetanDecoded == rawDecoded == unicodeDecoded)

    def test_fixDeprecated(self):
        deprecated = u"\u0f76\u0f77\u0f78\u0f79\u0f81"
        fixed = util.fixDeprecated(deprecated)
        expected = (u'\u0fb2\u0f80\u0fb2\u0f71\u0f80\u0fb3\u0f80\u0fb3\u0f71'
                    u'\u0f80\u0f71\u0f80')
        self.assertEqual(fixed, expected)

    def test_getUnicode(self):
        unichar = util.getUnicode("TIBETAN MARK INTERSYLLABIC TSHEG")
        self.assertEqual(unichar, u"\u0f0b")
        unichar = util.getUnicode("TIBETAN MARK DELIMITER TSHEG BSTAR")
        self.assertEqual(unichar, u"\u0f0c")
