from pyparsing import (
    oneOf, Combine, Group, OneOrMore, Optional, Word, ZeroOrMore)

from tibetan.translit.unicode import mapper
from tibetan import util


#alphas = u''.join(unichr(x) for x in xrange(0x0f0b, 0x0fd4))
#allLetters = Word("".join(mapper.unicodeLetters))

# letter collections by unicode functionality
topLetters = Word("".join(mapper.unicodeTop), exact=1).setName("top letters")
subjoinedLetters = Word(
    "".join(mapper.unicodeSubjoined)).setName("subjoined letters")
finalLetters = Word("".join(mapper.unicodeFinal)).setName("final letters")
vowels = Word("".join(mapper.unicodeVowels), exact=1).setName("vowels")

# legal combinations of letters in individual letter stacks
stacks = Group(OneOrMore(Combine(
    topLetters.setResultsName("top") + 
    ZeroOrMore(subjoinedLetters).setResultsName("subjoined") + 
    Optional(vowels).setResultsName("vowel")
    ).setResultsName("stack"))).setResultsName("stacks")

# syllable and sentence punctuation
tsheg = oneOf(u"%s %s" % (
    util.getUnicode("TIBETAN MARK INTERSYLLABIC TSHEG"),
    util.getUnicode("TIBETAN MARK DELIMITER TSHEG BSTAR"))).setName("tsheg")
shad = Word(util.getUnicode("TIBETAN MARK SHAD")).setName("shad")
nyisShad = Word(util.getUnicode("TIBETAN MARK NYIS SHAD")).setName("nyis shad")
gterTsheg = Word(
    util.getUnicode("TIBETAN MARK GTER TSHEG")).setName("gter tsheg")
sentenceEnd = ((tsheg + shad) | shad | gterTsheg).setName("sentence end")

# combinations of stacks to form syllables and sentences
basicSyllable = OneOrMore(stacks)
# XXX naming this None is a goofy work around for getting the data structure to
# make intuitive sense. Find another way.
syllable = Group(
    basicSyllable + Optional(tsheg.suppress())).setResultsName("None")
# XXX related to the goofy hack above, naming the sentence result as
# 'syllables' is also very goofy. Fix it.
sentence = Group(
    OneOrMore(syllable) + 
    Optional(basicSyllable) +
    Optional(sentenceEnd.setResultsName("end").suppress())
    ).setResultsName("syllables")
