# -*- coding: utf-8 -*-
from unittest import TestCase

from tibetan.translit.unicode import grammar


class GrammarTestCase(TestCase):

    def test_simpleWord(self):
        tibetan = "བ་།".decode("utf-8")
        parsed = grammar.sentence.parseString(tibetan)
        for sentences in parsed.asList():
            for syllables in sentences:
                for stacks in syllables:
                    for stack in stacks:
                        self.assertEqual(stack[0], u"\u0f56")

    def test_simpleWordWithoutShad(self):
        tibetan = "བ་".decode("utf-8")
        parsed = grammar.sentence.parseString(tibetan)
        for sentences in parsed.asList():
            for syllables in sentences:
                for stacks in syllables:
                    for stack in stacks:
                        self.assertEqual(stack[0], u"\u0f56")

    def test_simpleWordWithoutTsheg(self):
        tibetan = "བ".decode("utf-8")
        parsed = grammar.sentence.parseString(tibetan)
        for sentences in parsed.asList():
            for syllables in sentences:
                for stacks in syllables:
                    for stack in stacks:
                        self.assertEqual(stack[0], u"\u0f56")

    def test_wordWithStacks(self):
        tibetan = "སྐྱོབ་།".decode("utf-8")
        parsed = grammar.sentence.parseString(tibetan)
        for sentences in parsed.asList():
            for syllables in sentences:
                for stacks in syllables:
                    #import pdb;pdb.set_trace()
                    self.assertEqual(stacks[0][0], u"\u0f66\u0f90\u0fb1\u0f7c")
                    self.assertEqual(stacks[1][0], u"\u0f56")

    def test_sentence(self):
        tibetan = "ཁ་ས་མི་ཕྱུག་པོ་འདིའི་ཁང་པ་གོང་ཆེན་པོ་ཞིག་གཟིགས་སོང་།".decode("utf-8")
        sentence = grammar.sentence.parseString(tibetan)
        self.assertEqual(
            sentence.syllables[3].stacks.asList(), 
            [[u'\u0f55\u0fb1\u0f74'], [u'\u0f42']])
        #import pdb;pdb.set_trace()
        self.assertEqual(
            sentence.syllables[3].stacks[0][0], u'\u0f55\u0fb1\u0f74')
        self.assertEqual(
            sentence.syllables[3].stacks[1][0], u'\u0f42')
        self.assertEqual(
            sentence.syllables[5].stacks[0][0], u'\u0f60')
        self.assertEqual(
            sentence.syllables[5].stacks[1][0], u'\u0f51\u0f72')
        self.assertEqual(sentence.syllables[5].stacks[2][0], u'\u0f60\u0f72')
        self.assertEqual(sentence.syllables[13].stacks[0][0], u'\u0f66\u0f7c')
        self.assertEqual(sentence.syllables[13].stacks[1][0], u'\u0f44')

    def test_sentences(self):
        #tibetan = "ཕྱུག།སོང་།".decode("utf-8")
        #sentences = grammar.sentence.parseString(tibetan)
        #import pdb;pdb.set_trace()
        pass
