# -*- coding: utf-8 -*-
from unittest import TestCase

from tibetan.translit.unicode import mapper, parser
from tibetan.testing.wordlist.unicode import words as unicode_word_list
from tibetan import util


tibetan_stack = "བསྐྲོགས་"
unicode_stack = tibetan_stack.decode("utf-8")
tibetan_words = (
    "རྒྱུད་ཀྱི་རྒྱལ་"
    "ོ་ཆེན་པོ་སྒྱུ་འ"
    "ཕྲུལ་འདྲྭ་བ་")
unicode_words = tibetan_words.decode("utf-8")


class UnicodeParserFunctionsTestCase(TestCase):

    def test_decode(self):
        tibetan_result = util.decode(tibetan_stack)
        unicode_result = util.decode(unicode_stack)
        self.assertEquals(tibetan_result, unicode_result)

    def test_is_stack(self):
        pass

    def test_is_word(self):
        self.assertEqual(mapper.tib_top.get(unicode_stack[0]), "b")
        self.assertEqual(mapper.tib_other.get(unicode_stack[-1]), " ")
        self.assertTrue(parser.is_word(unicode_stack[0]))
        self.assertFalse(parser.is_word(unicode_stack[-1]))

    def test_parse_stack(self):
        #for word in unicode_word_list:
        #    parser.parse_stack(word)
        #parser.parse_stack(unicode_word_list[8])
        #parser.parse_stack(unicode_word_list[36])
        #parser.parse_stack(unicode_word_list[102])
        #parser.parse_stack(unicode_word_list[130])
        #parser.parse_stack(unicode_word_list[133])
        #parser.parse_stack(unicode_word_list[144])
        #parser.parse_stack(unicode_word_list[147])
        #parser.parse_stack(unicode_word_list[161])
        #parser.parse_stack(unicode_word_list[406])
        #parser.parse_stack(unicode_word_list[415])
        #parser.parse_stack(unicode_word_list[457])
        #parser.parse_stack(unicode_word_list[478])
        #parser.parse_stack(unicode_word_list[527])
        parser.parse_stack(unicode_word_list[589])


class StackTestCase(TestCase):

    def setUp(self):
        self.tibetan = tibetan_stack
        self.unicode = unicode_stack
        self.stack = parser.Stack(self.unicode)
        self.assertEqual(
            repr(self.tibetan),
            (r"'\xe0\xbd\x96\xe0\xbd\xa6\xe0\xbe\x90\xe0\xbe\xb2\xe0\xbd\xbc"
             r"\xe0\xbd\x82\xe0\xbd\xa6\xe0\xbc\x8b'"))
        self.assertEqual(
            repr(self.unicode),
            r"u'\u0f56\u0f66\u0f90\u0fb2\u0f7c\u0f42\u0f66\u0f0b'")

    def test_init_with_tibetan(self):
        stack = parser.Stack(self.tibetan)
        self.assertEqual(stack.text, self.unicode)

    def test_init_with_unicode(self):
        stack = parser.Stack(self.unicode)
        self.assertEqual(stack.text, self.unicode)

    def test_scan_for_end(self):
        index = self.stack._scan_for_end()
        self.assertEquals(index, 6)

    def test_scan_for_end_with_multiple_stacks(self):
        stack = parser.Stack(self.tibetan)
        index = stack._scan_for_end()
        self.assertEqual(index, 0)

    def test_scan_for_end_with_custom_index(self):
        pass

    def test_parse(self):
        pass


class UnicodeParserTestCase(TestCase):

    def setUp(self):
        self.parser = parser.UnicodeParser()
        self.tibetan_unicode = (
            u'\ufeff\u0f66\u0f7a\u0f58\u0f66\u0f0b\u0f45\u0f53\u0f0b\u0f50'
            u'\u0f58\u0f66\u0f0b\u0f45\u0f51')

    def test_to_wylie(self):
        #wylie = self.parser.to_wylie(self.tibetan_unicode)
        #expected = "sems can thams cad"
        #self.assertEqual(wylie, expected)
        pass

    def test_to_wylie_one_tsek_bar(self):
        pass

    def test_to_wylie_one_stack(self):
        index = 0
        tokens_parsed, stack, warns = self.parser._to_wylie_one_stack(
            self.tibetan_unicode, index)
        self.assertEqual(tokens_parsed, 2)
        self.assertEqual(stack.vowels, ["e"])
        self.assertEqual(stack.top, "s")
        self.assertEqual(stack.vowels, ["s"])

