"""
Perl version, (c) 2008, Roger Espel Llima <rogerespel@yahoo.com>
(c) 2010, Duncan McGreggor <duncan@ubuntu.com>
"""
from tibetan.translit.wylie import mapper


# defaults for conversion
CHECK = True
CHECK_STRICT = True
PRINT_WARNINGS = True
FIX_SPACING = True

regex_meta_characters = [
    "\\", ".", "^", "$", "*", "+", "-", "?", "{", "[", "]", "|", "(", ")", "/",
    "~", "`"]

# Precompute the regexp to split a string into Wylie tokens.  Sort by
# decreasing size so that things like "sh" don't get split into ("s", "h").
# the "." and the "/s" at the end ensure that any remaining characters are
# taken as a single-char token.
def process_tokens(token_list):
    filtered = [x for x in token_list if len(x) > 1 and not x.startswith("\u")]
    filtered.sort()
    filtered.sort(cmp=lambda a, b: len(b) - len(a))
    return filtered


def stringify_tokens(tokens):
    joined = "|".join(tokens)
    for meta in regex_meta_characters:
        if meta == "|":
            continue
        elif meta == "\\":
            raw = "\\\\"
        else:
            raw = "\%s" % meta
        joined = joined.replace(meta, raw)
    return joined


combined = set(
    mapper.consonant.keys() +
    mapper.subjoined.keys() +
    mapper.vowel.keys() +
    mapper.final.keys() +
    mapper.other.keys())


all_tokens = process_tokens(combined)
tokens_regexp1 = stringify_tokens(all_tokens)
tokens_regexp = "(?s-xim:(%s|\\u....|\\U........|\\.|\r\n|.))" % tokens_regexp1


class WylieParser(object):

    def __init__(self):
        pass

    def to_unicode(self, string):
        pass

    def get_warnings(self):
        pass

    def _get_consonant_string(self, tokens):
        pass

    def _get_consonant_string_backwards(self, tokens):
        pass

    def _to_unicode_one_stack(self, tokens, index):
        pass

    def _to_unicode_one_tsek_bar(self, tokens, index):
        pass
