from unittest import TestCase

from tibetan.translit.wylie import parser


class WylieParserTokensTestCase(TestCase):

    def test_process_tokens(self):
        tokens = ['a', 'bbbb', 'cc', 'dd', 'eee', 'fff']
        expected = ['bbbb', 'eee', 'fff', 'cc', 'dd']
        results = parser.process_tokens(tokens)
        self.assertEqual(results, expected)

    def test_stringify_tokens(self):
        tokens = ["cat", "in", "the", "hat"]
        results = parser.stringify_tokens(tokens)
        self.assertEqual(results, "cat|in|the|hat")

    def test_stringify_tokens_with_meta(self):
        results = parser.stringify_tokens(parser.regex_meta_characters)
        expected = "\\\\|\.|\^|\$|\*|\+|\-|\?|\{|\[|\]|||\(|\)|\/|\~|\`"
        self.assertEqual(results, expected)

    def test_all_tokens(self):
        expected = (
            "-d+hdz+h-dh-sh-thD+hb+hd+hdzhg+htsh~M`-I-d-i-n-t//DhShThaiaubhchd"
            "hdzghkhngnyphshthtszh~M~X")
        self.assertEquals("".join(parser.all_tokens), expected)

    def test_tokens_regexp(self):
        expected = (
            "(?s-xim:(\-d\+h|dz\+h|\-dh|\-sh|\-th|D\+h|b\+h|d\+h|dzh|g\+h|tsh|"
            "\~M\`|\-I|\-d|\-i|\-n|\-t|\/\/|Dh|Sh|Th|ai|au|bh|ch|dh|dz|gh|kh|"
            "ng|ny|ph|sh|th|ts|zh|\~M|\~X|\\u....|\\U........|\\.|\r\n|.))")
        self.assertEquals(parser.tokens_regexp, expected)


class WylieParserTestCase(TestCase):
    pass
